@@ -1,22 +1,23 @@
-/***************************************************************************
-                           playlist.cpp
-                           -------------------
-    begin                : Die Apr 22 2003
-    copyright            : (C) 2003-2005 by Jrgen Kofler <kaffeine@gmx.net>
-    copyright            : (C) 2005-2006 by Christophe Thommeret <hftom@free.fr>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
-
+/*
+ * playlist.cpp
+ *
+ * Copyright (C) 2003-2005 Jürgen Kofler <kaffeine@gmx.net>
+ * Copyright (C) 2005-2006 Christophe Thommeret <hftom@free.fr>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #include <krandomsequence.h>
 #include <kapplication.h>
@@ -186,9 +187,9 @@ struct CoverPopup : public QWidget
 CoverFrame::CoverFrame( QWidget *parent ) : QFrame( parent )
 {
 	imagePath = "";
-	QString path = locate("appdata", "nocover");
+	QString path = locate("appdata", "nocover.png");
 	if ( !path )
-		path = locate("data", "kaffeine/nocover");
+		path = locate("data", "kaffeine/nocover.png");
 	noCoverPix.convertFromImage( QImage(path) );
 	setPaletteBackgroundPixmap( noCoverPix );
 }
@@ -219,7 +220,6 @@ void CoverFrame::popup( const QPixmap &pix ) const
 {
     QPoint mouse  = QCursor::pos();
     QRect desktop = KApplication::desktop()->screenGeometry(mouse);
-
     int x = mouse.x();
     int y = mouse.y();
     int height = pix.height() + 4;
@@ -1681,9 +1681,9 @@ void PlayList::setCover( QString s1, QString s2, bool forceFetch )
 				coverFrame->setCoverPixmap( fname );
 		}
 		else if ( !forceFetch && m_cover ) {
-			QString path = locate("appdata", "nocover");
+			QString path = locate("appdata", "nocover.png");
 			if ( !path )
-				path = locate("data", "kaffeine/nocover");
+				path = locate("data", "kaffeine/nocover.png");
 			KIO::file_copy( KURL::fromPathOrURL( path ), KURL::fromPathOrURL( fname ), -1, true );
 		}
 	}
