@@ -1,20 +1,22 @@
-/***************************************************************************
-                          dvbconfig.cpp  -  description
-                             -------------------
-    begin                : Wed Apr 21 2004
-    copyright            : (C) 2004-2005 by Christophe Thommeret
-    email                : hftom@free.fr
-    last modified        : $Date: 2005/08/27 00:35:28 $ by $Author: hftom $
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * dvbconfig.cpp
+ *
+ * Copyright (C) 2004-2006 Christophe Thommeret <hftom@free.fr>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #include <fcntl.h>
 #include <sys/ioctl.h>
@@ -40,8 +42,6 @@
 #include "gdvb.h"
 #include "kaffeinedvbplugin.h"
 
-
-
 MSpinBox::MSpinBox( QWidget *parent, int devNum ) : QSpinBox( 1, 4, 1, parent )
 {
 	deviceNumber = devNum;
@@ -134,25 +134,27 @@ bool DVBconfig::haveDvbDevice()
 {
 	int i=0, j=0, res, fdFrontend=0;
 	struct dvb_frontend_info info;
-	bool ret = false;
+	fprintf(stderr,"%d\n", errno);
 
-	while ( i>=0 ) {
+	while ( i>=0 && i<10 ) {
 		j = 0;
-		while ( j>=0 ) {
+		while ( j>=0 && j<4 ) {
 			fdFrontend = open( QString("/dev/dvb/adapter%1/frontend%2").arg( i ).arg( j ).ascii(), O_RDWR);
 			if ( fdFrontend<0 ) {
-				perror( QString("/dev/dvb/adapter%1/frontend%2 : ").arg( i ).arg( j ).ascii() );
-				if ( j==0 )
-					i = -1;
-				j=-1;
+				if ( errno==ENOENT ) {
+					if ( j==0 )
+						i = -1;
+					j=-1;
+				}
+				else
+					++j;
 			}
 			else {
-				if ( (res = ioctl( fdFrontend, FE_GET_INFO, &info ) < 0) ) {
+				if ( (res = ioctl( fdFrontend, FE_GET_INFO, &info ) < 0) )
 					perror( QString("/dev/dvb/adapter%1/frontend%2 FE_GET_INFO: ").arg( i ).arg( j ).ascii() );
-				}
 				else {
-					fprintf(stderr,"/dev/dvb/adapter%d/frontend%d : opened ( %s )\n", i, j, info.name );
-					ret = true;
+					close( fdFrontend );
+					return true;
 				}
 				close( fdFrontend );
 				++j;
@@ -162,7 +164,7 @@ bool DVBconfig::haveDvbDevice()
 			++i;
 	}
 
-	return ret;
+	return false;
 }
 
 
@@ -173,14 +175,19 @@ void DVBconfig::startup()
 	struct dvb_frontend_info info;
 	bool as;
 
-	while ( i>=0 ) {
+	while ( i>=0 && i<10 ) {
 		j = 0;
-		while ( j>=0 ) {
+		while ( j>=0 && j<4 ) {
 			fdFrontend = open( QString("/dev/dvb/adapter%1/frontend%2").arg( i ).arg( j ).ascii(), O_RDWR);
 			if ( fdFrontend<0 ) {
-				if ( j==0 )
-					i = -1;
-				j=-1;
+				perror( QString("/dev/dvb/adapter%1/frontend%2 : ").arg( i ).arg( j ).ascii() );
+				if ( errno==ENOENT ) {
+					if ( j==0 )
+						i = -1;
+					j=-1;
+				}
+				else
+					++j;
 			}
 			else {
 				if ( !(res = ioctl( fdFrontend, FE_GET_INFO, &info ) < 0) ) {
@@ -194,8 +201,7 @@ void DVBconfig::startup()
 					else
 						as = false;
 					devList.append( new Device( i, j, info.type, info.name, as ) );
-
-
+					fprintf(stderr,"/dev/dvb/adapter%d/frontend%d : opened ( %s )\n", i, j, info.name );
 				}
 				close( fdFrontend );
 				++j;
@@ -350,6 +356,25 @@ void DVBconfig::changeIconCategory( const QString &name, const QString &icon )
 
 
 
+int DVBconfig::readDvbChanOrder()
+{
+	config->setGroup( "DVB Options" );
+	int sort = config->readNumEntry("ChannelsSorting", 0);
+	return sort;
+}
+
+
+
+void DVBconfig::saveDvbChanOrder( int s, int col )
+{
+	int sort = (s<<1) | col;
+	config->setGroup( "DVB Options" );
+	config->writeEntry("ChannelsSorting", sort);
+	config->sync();
+}
+
+
+
 void DVBconfig::readConfig()
 {
 	QSize size;
@@ -961,12 +986,19 @@ LnbConfig::LnbConfig( LNB *b, QWidget *parent ) :
 	univ = new QPushButton( i18n("Universal LNB"), page );
 	connect( univ, SIGNAL(clicked()), this, SLOT(setUniversal()) );
 	vb->addWidget( univ );
+	cmono = new QPushButton( i18n("C-Band LNB"), page );
+	connect( cmono, SIGNAL(clicked()), this, SLOT(setCBandMono()) );
+	vb->addWidget( cmono );
+	cmulti = new QPushButton( i18n("C-Band Multipoint LNB"), page );
+	connect( cmulti, SIGNAL(clicked()), this, SLOT(setCBandMulti()) );
+	vb->addWidget( cmulti );
 
 	grid = new QGridLayout( 0, 1, 1 );
-	nLO = new QButtonGroup( 2, Qt::Horizontal, page );
+	nLO = new QButtonGroup( 3, Qt::Horizontal, page );
 	connect( nLO, SIGNAL(clicked(int)), this, SLOT(setDual(int)) );
 	new QRadioButton( i18n("Dual LO"), nLO );
 	new QRadioButton( i18n("Single LO"), nLO );
+	new QRadioButton( i18n("H/V LO"), nLO );
 	grid->addMultiCellWidget( nLO, 0, 0, 0, 1 );
 	slofLab = new QLabel( i18n("Dual LO switch frequency:")+i18n(" (MHz)"), page );
 	grid->addWidget( slofLab, 1, 0 );
@@ -984,6 +1016,14 @@ LnbConfig::LnbConfig( LNB *b, QWidget *parent ) :
 	grid->addWidget( singleLab, 4, 0 );
 	single = new QSpinBox( 0, 13000, 1, page );
 	grid->addWidget( single, 4, 1 );
+	verticalLab = new QLabel( i18n("Vertical pol. LO frequency:")+i18n(" (MHz)"), page );
+	grid->addWidget( verticalLab, 5, 0 );
+	vertical = new QSpinBox( 0, 13000, 1, page );
+	grid->addWidget( vertical, 5, 1 );
+	horizontalLab = new QLabel( i18n("Horizontal pol. LO frequency:")+i18n(" (MHz)"), page );
+	grid->addWidget( horizontalLab, 6, 0 );
+	horizontal = new QSpinBox( 0, 13000, 1, page );
+	grid->addWidget( horizontal, 6, 1 );
 
 	vb->addLayout( grid );
 	vb->addItem( new QSpacerItem( 20, 20, QSizePolicy::Ignored, QSizePolicy::Ignored ) );
@@ -993,14 +1033,22 @@ LnbConfig::LnbConfig( LNB *b, QWidget *parent ) :
 	lo->setValue( lnb->loFreq );
 	hi->setValue( lnb->hiFreq );
 	single->setValue( lnb->loFreq );
+	vertical->setValue( lnb->loFreq );
+	horizontal->setValue( lnb->hiFreq );
 
 	if ( lnb->switchFreq ) {
 		nLO->setButton( 0 );
 		setDual( 0 );
 	}
 	else {
-		nLO->setButton( 1 );
-		setDual( 1 );
+		if ( lnb->hiFreq ) {
+			nLO->setButton( 2 );
+			setDual( 2 );
+		}
+		else {
+			nLO->setButton( 1 );
+			setDual( 1 );
+		}
 	}
 }
 
@@ -1008,25 +1056,52 @@ LnbConfig::LnbConfig( LNB *b, QWidget *parent ) :
 
 void LnbConfig::setDual( int id )
 {
-	if ( id==0 ) {
-		singleLab->hide();
-		single->hide();
-		slofLab->show();
-		slof->show();
-		loLab->show();
-		lo->show();
-		hiLab->show();
-		hi->show();
-	}
-	else {
-		slofLab->hide();
-		slof->hide();
-		loLab->hide();
-		lo->hide();
-		hiLab->hide();
-		hi->hide();
-		singleLab->show();
-		single->show();
+	switch ( id ) {
+		case 0: {
+			singleLab->hide();
+			single->hide();
+			verticalLab->hide();
+			vertical->hide();
+			horizontalLab->hide();
+			horizontal->hide();
+			slofLab->show();
+			slof->show();
+			loLab->show();
+			lo->show();
+			hiLab->show();
+			hi->show();
+			break;
+		}
+		case 1: {
+			slofLab->hide();
+			slof->hide();
+			loLab->hide();
+			lo->hide();
+			hiLab->hide();
+			hi->hide();
+			verticalLab->hide();
+			vertical->hide();
+			horizontalLab->hide();
+			horizontal->hide();
+			singleLab->show();
+			single->show();
+			break;
+		}
+		case 2: {
+			slofLab->hide();
+			slof->hide();
+			loLab->hide();
+			lo->hide();
+			hiLab->hide();
+			hi->hide();
+			singleLab->hide();
+			single->hide();
+			verticalLab->show();
+			vertical->show();
+			horizontalLab->show();
+			horizontal->show();
+			break;
+		}
 	}
 }
 
@@ -1039,22 +1114,50 @@ void LnbConfig::setUniversal()
 	slof->setValue( 11700 );
 	lo->setValue( 9750 );
 	hi->setValue( 10600 );
-	single->setValue( 9750 );
+}
+
+
+
+void LnbConfig::setCBandMono()
+{
+	nLO->setButton( 1 );
+	setDual( 1 );
+	single->setValue( 5150 );
+}
+
+
+
+void LnbConfig::setCBandMulti()
+{
+	nLO->setButton( 2 );
+	setDual( 2 );
+	vertical->setValue( 5150 );
+	horizontal->setValue( 5750 );
 }
 
 
 
 void LnbConfig::accept()
 {
-	if ( nLO->selectedId() ) {
-		lnb->switchFreq = 0;
-		lnb->hiFreq = 0;
-		lnb->loFreq = single->value();
-	}
-	else {
-		lnb->switchFreq = slof->value();
-		lnb->loFreq = lo->value();
-		lnb->hiFreq = hi->value();
+	switch ( nLO->selectedId() ) {
+		case 0: {
+			lnb->switchFreq = slof->value();
+			lnb->loFreq = lo->value();
+			lnb->hiFreq = hi->value();
+			break;
+		}
+		case 1: {
+			lnb->switchFreq = 0;
+			lnb->hiFreq = 0;
+			lnb->loFreq = single->value();
+			break;
+		}
+		case 2: {
+			lnb->switchFreq = 0;
+			lnb->loFreq = vertical->value();
+			lnb->hiFreq = horizontal->value();
+			break;
+		}
 	}
 	done( Accepted );
 }
