@@ -1,19 +1,22 @@
-/***************************************************************************
-                          scandialog.cpp  -  description
-                             -------------------
-    begin                : Mon Mar 22 2004
-    copyright            : (C) 2004-2006 by Christophe Thommeret
-    email                : hftom@free.fr
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * scandialog.cpp
+ *
+ * Copyright (C) 2004-2006 Christophe Thommeret <hftom@free.fr>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #include <qlayout.h>
 #include <qdir.h>
@@ -157,6 +160,7 @@ ScanDialog::ScanDialog( QPtrList<DvbStream> *d, QPtrList<ChannelDesc> *ch, QSize
 	connect( channelsList, SIGNAL(doubleClicked(QListViewItem*,const QPoint &,int)), this, SLOT( slotChannelChanged(QListViewItem*,const QPoint &,int) ) );
 	connect( newBtn, SIGNAL(clicked()), this, SLOT(newChannel()) );
 	connect( delBtn, SIGNAL(clicked()), this, SLOT(deleteAll()) );
+	connect( selectallBtn, SIGNAL(clicked()), this, SLOT(selectAll()) );
 
 	QAccel *ac = new QAccel( channelsList );
 	ac->insertItem( Key_Delete, 100 );
@@ -168,6 +172,13 @@ ScanDialog::ScanDialog( QPtrList<DvbStream> *d, QPtrList<ChannelDesc> *ch, QSize
 
 
 
+void ScanDialog::selectAll()
+{
+	foundList->selectAll( true );
+}
+
+
+
 void ScanDialog::slotChannelChanged( QListViewItem *_channel, const QPoint &, int )
 {
 	if ( !_channel )
@@ -617,18 +628,39 @@ bool ScanDialog::getTransData()
 
 
 
+void ScanDialog::checkDuplicateName( ChannelDesc *chan )
+{
+	QString org, name;
+	int i, j=1;
+	bool loop;
+
+	org = name = chan->name;
+	
+	do {
+		loop = false;
+		for ( i=0; i<(int)chandesc->count(); i++ ) {
+			if ( name==chandesc->at(i)->name ) {
+				name = org+"-"+QString().setNum(j);
+				loop = true;
+				++j;
+				break;
+			}
+		}
+	} while ( loop );
+	chan->name = name;
+}
+
+
+
 void ScanDialog::addSelected()
 {
 	ChannelDesc *chan;
 	DListViewItem *dit, *odit;
 	QListViewItem *it;
-	int n, r;
-	QStringList list;
 
 	dit = (DListViewItem*)foundList->firstChild();
 	while( dit ) {
 		chan = 0;
-		r = 0;
 		if ( !dit->isSelected( ) ) {
 			dit = (DListViewItem*)dit->nextSibling();
 			continue;
@@ -638,17 +670,9 @@ void ScanDialog::addSelected()
 			dit = (DListViewItem*)dit->nextSibling();
 			continue;
 		}
-		for ( n=0; n<(int)chandesc->count(); n++ ) {
-			if ( chan->name==chandesc->at(n)->name ) {
-				r++;
-				list.append( chan->name );
-				break;
-			}
-		}
-		if ( r ) {
-			dit = (DListViewItem*)dit->nextSibling();
-			continue;
-		}
+
+		checkDuplicateName( chan );
+
 		chan->num = chandesc->count()+1;
 		chandesc->append( new ChannelDesc( *chan ) );
 		it = new QListViewItem( channelsList, chan->name );
@@ -669,8 +693,6 @@ void ScanDialog::addSelected()
 		delete odit;
 		dvbsi->channels.remove( chan );
 	}
-	if ( list.count() )
-		KMessageBox::informationList( this, i18n("These channels already exist and were not added:"), list );
 }
 
 
@@ -689,13 +711,11 @@ void ScanDialog::working( bool b )
 
 void ScanDialog::addFiltered()
 {
-	int j;
 	ChannelDesc *chan;
 	QListViewItem *it;
 	DListViewItem *dit, *odit;
 	int m = dvbsi->channels.count();
 	int t=0;
-	QStringList list;
 
 	working( true );
 	startBtn->setEnabled( false );
@@ -755,20 +775,9 @@ void ScanDialog::addFiltered()
 			dit = (DListViewItem*)dit->nextSibling();
 			continue;
 		}
-		j = 0;
-		it = channelsList->firstChild();
-		while ( it!=0 ) {
-			if ( chan->name==it->text(0) ) {
-				list.append( chan->name );
-				j++;
-				break;
-			}
-			it = it->nextSibling();
-		}
-		if ( j ) {
-			dit = (DListViewItem*)dit->nextSibling();
-			continue;
-		}
+
+		checkDuplicateName( chan );
+
 		chan->num = chandesc->count()+1;
 		chandesc->append( new ChannelDesc( *chan ) );
 		it = new QListViewItem( channelsList, chan->name );
@@ -790,8 +799,7 @@ void ScanDialog::addFiltered()
 		delete odit;
 		dvbsi->channels.remove( chan );
 	}
-	if ( list.count() )
-		KMessageBox::informationList( this, i18n("These channels already exist and were not added:"), list );
+
 	progress->setProgress(0);
 	startBtn->setEnabled( true );
 	working( false );
